==> pan-0.7.0.tar.gz: pan-0.7.0/pan/queue-item-send.c <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

/*********************
**********************  Includes
*********************/

#include <stdlib.h>
#include <string.h>

#include <glib.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>

#include "acache.h"
#include "article.h"
#include "article-db.h"
#include "debug.h"
#include "log.h"
#include "message-send.h"
#include "queue.h"
#include "queue-item-send.h"
#include "text.h"

/*********************
**********************  Defines / Enumerated types
*********************/

/*********************
**********************  Macros
*********************/

/*********************
**********************  Structures / Typedefs
*********************/

/*********************
**********************  Private Function Prototypes
*********************/

static void queue_item_send_class_init (QueueItemSendClass *klass);

static void queue_item_send_init (QueueItemSend *item);

static gint queue_item_send_run (QueueItem* item);

static void queue_item_send_destroy (GtkObject* item);

static gchar* queue_item_send_describe (StatusItem* item);

/*********************
**********************  Variables
*********************/

/***********
************  Extern
***********/

extern gboolean must_exit;

/***********
************  Public
***********/

/***********
************  Private
***********/

static QueueItemClass *parent_class = NULL;

/*********************
**********************  BEGINNING OF SOURCE
*********************/

/************
*************  PUBLIC ROUTINES
************/

GtkType
queue_item_send_get_type (void)
{
	static GtkType queue_item_send_type = 0;

	if (!queue_item_send_type)
	{
		static const GtkTypeInfo queue_item_send_info =
		{
			"QueueItemSend",
			sizeof(QueueItemSend),
			sizeof(QueueItemSendClass),
			(GtkClassInitFunc) queue_item_send_class_init,
			(GtkObjectInitFunc) queue_item_send_init,
			/* reserved_1 */ NULL,
			/* reserved_2 */ NULL,
			(GtkClassInitFunc) NULL
		};

		queue_item_send_type = gtk_type_unique (
			TYPE_QUEUE_ITEM,
			&queue_item_send_info);
	}

	return queue_item_send_type;
}

static void
queue_item_send_class_init (QueueItemSendClass *klass)
{
        parent_class = gtk_type_class (TYPE_QUEUE_ITEM);

	GTK_OBJECT_CLASS(klass)->destroy = queue_item_send_destroy;
	STATUS_ITEM_CLASS(klass)->describe = queue_item_send_describe;
	QUEUE_ITEM_CLASS(klass)->run = queue_item_send_run;
}

static void
queue_item_send_init (QueueItemSend *item)
{
	item->msg = NULL;
}

/*****
******
*****/

GtkObject*
queue_item_send_new (server_data *sdata, Message *msg)
{
	QueueItemSend *item = NULL;

	/* sanity checks */
	g_return_val_if_fail(sdata!=NULL, NULL);
#if 0
	g_return_val_if_fail(msg!=NULL, NULL);
	g_return_val_if_fail(msg->message_id!=NULL, NULL);
	g_return_val_if_fail(*msg->message_id!='\0', NULL);
#endif

	/* gtk instantiation */
	item = QUEUE_ITEM_SEND(gtk_type_new(TYPE_QUEUE_ITEM_SEND));

	/* construct superclass... */
	queue_item_construct (QUEUE_ITEM(item), sdata, TRUE, TRUE);

	/* construct this class... */
	item->msg = msg;

	return GTK_OBJECT(item);
}

/*****
******
*****/
static gchar*
queue_item_send_describe (StatusItem* item)
{
	/* sanity checks */
        g_return_val_if_fail (item!=NULL, 0);
	g_return_val_if_fail (IS_QUEUE_ITEM_SEND(item), 0);
        g_return_val_if_fail (QUEUE_ITEM(item)->sdata!=NULL, 0);
	g_return_val_if_fail (GTK_OBJECT_CONSTRUCTED(item), 0);
#if 0
	g_return_val_if_fail (QUEUE_ITEM_SEND(item)->msg!=NULL, 0);
	g_return_val_if_fail (QUEUE_ITEM_SEND(item)->msg->message_id!=NULL, 0);
	g_return_val_if_fail (*QUEUE_ITEM_SEND(item)->msg->message_id!='\0', 0);
#endif

	return g_strdup_printf ("Sending Message");
}

/*****
******
*****/

static void
queue_item_send_destroy (GtkObject* object)
{
        debug (DEBUG_QUEUE,
		"GtkObject '%p' in queue_item_send_destroy", object);

	/* sanity checks */
        g_return_if_fail (object != NULL);
	g_return_if_fail (IS_QUEUE_ITEM_SEND (object));
	g_return_if_fail (GTK_OBJECT_CONSTRUCTED (object));

	/* clean up this class */
	/* (nothing -- text_update() frees the Message) */

	/* invoke superclass */
	if (GTK_OBJECT_CLASS(parent_class)->destroy)
		(*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
}
/*****
******
*****/

static gint
queue_item_send_run (QueueItem* item)
{
	int retval = 0;

	/* sanity checks */
	g_return_val_if_fail(item!=NULL, -1);
	g_return_val_if_fail(IS_QUEUE_ITEM_SEND(item), -1);
	g_return_val_if_fail(item->sock!=NULL, -1);
	g_return_val_if_fail(PAN_IS_SOCKET(item->sock), -1);
	//g_return_val_if_fail(QUEUE_ITEM_SEND(item)->msg!=NULL, -1);
	//g_return_val_if_fail(QUEUE_ITEM_SEND(item)->msg->message_id!=NULL,-1);
	//g_return_val_if_fail(*QUEUE_ITEM_SEND(item)->msg->message_id!='\0',-1);

	retval = message_send (
		STATUS_ITEM(item),
		QUEUE_ITEM(item)->sock, 
		QUEUE_ITEM_SEND(item)->msg);

	g_message ( "queue_item_send_run retval: %d", retval);
	status_item_emit_done (STATUS_ITEM(item), retval);

	return retval;
}

==> pan-0.7.3.tar.gz: pan-0.7.3/pan/queue-item-send.c <==
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Pan Development Team (pan@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

/*********************
**********************  Includes
*********************/

#include <stdlib.h>
#include <string.h>

#include <glib.h>
#include <libgnome/gnome-defs.h>
#include <libgnome/gnome-i18n.h>

#include "debug.h"
#include "message-send.h"
#include "queue-item-send.h"

/*********************
**********************  Defines / Enumerated types
*********************/

/*********************
**********************  Macros
*********************/

/*********************
**********************  Structures / Typedefs
*********************/

/*********************
**********************  Private Function Prototypes
*********************/

static gint queue_item_send_run (QueueItem* item);

static gchar* queue_item_send_describe (const StatusItem* item);

/*********************
**********************  Variables
*********************/

/***********
************  Extern
***********/

/***********
************  Public
***********/

/***********
************  Private
***********/

/*********************
**********************  BEGINNING OF SOURCE
*********************/

/************
*************  PUBLIC ROUTINES
************/

/*****
******
*****/

PanObject*
queue_item_send_new (server_data *sdata, Message *msg)
{
	QueueItemSend *item = g_new0 (QueueItemSend, 1);

	queue_item_constructor (QUEUE_ITEM(item),
		queue_item_destructor,
		queue_item_send_describe,
		queue_item_send_run, sdata, TRUE, TRUE);

	item->smtp_socket = NULL;
	item->msg = msg;

	return PAN_OBJECT(item);
}

/*****
******
*****/

static gchar*
queue_item_send_describe (const StatusItem* item)
{
	return g_strdup (_("Sending Message"));
}


static gint
queue_item_send_run (QueueItem* item)
{
	return message_send (
		STATUS_ITEM(item),
		QUEUE_ITEM(item)->sock, 
		QUEUE_ITEM_SEND(item)->msg);
}
